@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -17,9 +17,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <stdlib.h>	
-#include <string.h>
-#include <time.h>
+
+//#include <time.h>
+#include <stdlib.h>		/* atoi, atof, atol */
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
@@ -165,6 +165,7 @@ gchar label[256];
 
 	DB( g_print("\n[dateentry] update text\n") );
 
+	//%x : The preferred date representation for the current locale without the time.
 	g_date_strftime (label, 256 - 1, "%x", priv->date);
 	gtk_entry_set_text (GTK_ENTRY (priv->entry), label);
 	DB( g_print(" = %s\n", label) );
@@ -479,10 +480,11 @@ GtkDateEntryPrivate *priv;
                                                   GTK_TYPE_DATE_ENTRY,
                                                   GtkDateEntryPrivate);
 	priv = dateentry->priv;
-	
+
 	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET(dateentry)), GTK_STYLE_CLASS_LINKED);
 
 	priv->entry = gtk_entry_new ();
+	//todo: see if really useful
 	gtk_entry_set_width_chars(GTK_ENTRY(priv->entry), 16);
 	gtk_entry_set_max_width_chars(GTK_ENTRY(priv->entry), 16);
 	gtk_box_pack_start (GTK_BOX (dateentry), priv->entry, TRUE, TRUE, 0);
