@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -55,6 +55,30 @@ struct _archive
 };
 
 
+/* list define archive (defarchive) */
+enum
+{
+	LST_DEFARC_DATAS,
+	LST_DEFARC_OLDPOS,
+	LST_DEFARC_AUTO,
+	NUM_LST_DEFARC
+};
+
+/*
+** scheduled unit
+*/
+enum
+{
+	AUTO_UNIT_DAY,
+	AUTO_UNIT_WEEK,
+	AUTO_UNIT_MONTH,
+	//AUTO_UNIT_QUARTER,
+	AUTO_UNIT_YEAR
+};
+
+
+
+
 Archive *da_archive_malloc(void);
 Archive *da_archive_clone(Archive *src_item);
 guint archive_add_get_nbdays(void);
