@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -36,18 +36,11 @@ extern struct HomeBank *GLOBALS;
 extern struct Preferences *PREFS;
 
 
+/* = = = = = = = = = = = = = = = = */
 
-
-/* = = = = = = = = = = = = = = = = = = = = */
-/* Filter */
-
-Filter *da_filter_malloc(void)
-{
-	return g_malloc0(sizeof(Filter));
-}
-
-void da_filter_free(Filter *flt)
+void da_flt_free(Filter *flt)
 {
+	DB( g_print("da_flt_free\n") );
 	if(flt != NULL)
 	{
 		g_free(flt->memo);
@@ -57,55 +50,88 @@ void da_filter_free(Filter *flt)
 	}
 }
 
+
+Filter *da_flt_malloc(void)
+{
+	DB( g_print("da_flt_malloc\n") );
+	return g_malloc0(sizeof(Filter));
+}
+
+
 /* = = = = = = = = = = = = = = = = = = = = */
 
-gchar *filter_daterange_text_get(Filter *flt)
-{
-gchar buffer1[128];
-gchar buffer2[128];
-gchar buffer3[128];
-GDate *date;
-gchar *retval = NULL;
 
-	date = g_date_new_julian(flt->mindate);
-	g_date_strftime (buffer1, 128-1, PREFS->date_format, date);
-	
-	g_date_set_julian(date, flt->maxdate);
-	g_date_strftime (buffer2, 128-1, PREFS->date_format, date);
-	
-	if( flt->nbdaysfuture > 0 )
+void filter_status_acc_clear_except(Filter *flt, guint32 selkey)
+{
+GHashTableIter iter;
+gpointer key, value;
+
+	// set all account
+	g_hash_table_iter_init (&iter, GLOBALS->h_acc);
+	while (g_hash_table_iter_next (&iter, &key, &value))
 	{
-		g_date_set_julian(date, flt->maxdate + flt->nbdaysfuture);
-		g_date_strftime (buffer3, 128-1, PREFS->date_format, date);
-		retval = g_strdup_printf("%s — <s>%s</s> %s", buffer1, buffer2, buffer3);
+	Account *item = value;
+		item->flt_select = item->key == selkey ? TRUE : FALSE;
 	}
-	else
-		retval = g_strdup_printf("%s — %s", buffer1, buffer2);
-	
-	g_date_free(date);
 
-	//return g_strdup_printf(_("<i>from</i> %s <i>to</i> %s — "), buffer1, buffer2);
-	return retval;
+
 }
 
 
-
-static void filter_default_date_set(Filter *flt)
+void filter_status_pay_clear_except(Filter *flt, guint32 selkey)
 {
-	flt->mindate = HB_MINDATE;
-	flt->maxdate = HB_MAXDATE;
+GHashTableIter iter;
+gpointer key, value;
+
+	// set all payee
+	g_hash_table_iter_init (&iter, GLOBALS->h_pay);
+	while (g_hash_table_iter_next (&iter, &key, &value))
+	{
+	Payee *item = value;
+		item->flt_select = item->key == selkey ? TRUE : FALSE;
+	}
+
+
 }
 
 
-static void filter_clear(Filter *flt)
+void filter_status_cat_clear_except(Filter *flt, guint32 selkey)
 {
-guint i;
+GHashTableIter iter;
+gpointer key, value;
+
+	// set all payee
+	g_hash_table_iter_init (&iter, GLOBALS->h_cat);
+	while (g_hash_table_iter_next (&iter, &key, &value))
+	{
+	Category *item = value;
+		item->flt_select = item->key == selkey ? TRUE : FALSE;
+	}
+
+}
+
+
+/* = = = = = = = = = = = = = = = = */
+
+
+void filter_reset(Filter *flt)
+{
+gint i;
+
+	DB( g_print("\n[filter] default reset all %p\n", flt) );
 
 	for(i=0;i<FILTER_MAX;i++)
 	{
 		flt->option[i] = 0;
 	}
-	
+
+	flt->option[FILTER_DATE] = 1;
+	flt->range  = FLT_RANGE_LAST12MONTHS;
+	filter_preset_daterange_set(flt, flt->range, 0);
+
+	for(i=0;i<NUM_PAYMODE_MAX;i++)
+		flt->paymode[i] = TRUE;
+
 	g_free(flt->info);
 	g_free(flt->memo);
 	g_free(flt->tag);
@@ -113,60 +139,33 @@ guint i;
 	flt->memo = NULL;
 	flt->tag = NULL;
 
+	//unsaved
+	flt->nbdaysfuture = 0;
+	flt->type   = FLT_TYPE_ALL;
+	flt->status = FLT_STATUS_ALL;
+	flt->forceremind = PREFS->showremind;
+
 	*flt->last_tab = '\0';
 }
 
 
-void filter_default_all_set(Filter *flt)
+void filter_set_tag_by_id(Filter *flt, guint32 key)
 {
-GHashTableIter iter;
-gpointer key, value;
-gint i;
+Tag *tag;
 
-	DB( g_print("\n(filter) reset %p\n", flt) );
-
-	filter_clear(flt);
-
-	flt->nbdaysfuture = 0;
-
-	flt->range  = FLT_RANGE_LAST12MONTHS;
-	flt->type   = FLT_TYPE_ALL;
-	flt->status = FLT_STATUS_ALL;
-
-	flt->forceremind = PREFS->showremind;
-
-	flt->option[FILTER_DATE] = 1;
-	filter_default_date_set(flt);
-
-	for(i=0;i<NUM_PAYMODE_MAX;i++)
-		flt->paymode[i] = TRUE;
-
-	filter_preset_daterange_set(flt, flt->range, 0);
-
-	// set all account
-	g_hash_table_iter_init (&iter, GLOBALS->h_acc);
-	while (g_hash_table_iter_next (&iter, &key, &value))
+	DB( g_print("\n[filter] set tag by id\n") );
+	
+	if(flt->tag)
 	{
-	Account *item = value;
-		item->flt_select = TRUE;
+		g_free(flt->tag);
+		flt->tag = NULL;
 	}
 
-	// set all payee
-	g_hash_table_iter_init (&iter, GLOBALS->h_pay);
-	while (g_hash_table_iter_next (&iter, &key, &value))
+	tag = da_tag_get(key);
+	if(tag)
 	{
-	Payee *item = value;
-		item->flt_select = TRUE;
+		flt->tag = g_strdup(tag->name);
 	}
-
-	// set all payee
-	g_hash_table_iter_init (&iter, GLOBALS->h_cat);
-	while (g_hash_table_iter_next (&iter, &key, &value))
-	{
-	Category *item = value;
-		item->flt_select = TRUE;
-	}
-
 }
 
 
@@ -175,7 +174,7 @@ static void filter_set_date_bounds(Filter *flt, guint32 kacc)
 GList *lst_acc, *lnk_acc;
 GList *lnk_txn;
 
-	DB( g_print("\n(filter) set date bounds %p\n", flt) );
+	DB( g_print("\n[filter] set date bounds %p\n", flt) );
 
 	flt->mindate = 0;
 	flt->maxdate = 0;
@@ -186,7 +185,7 @@ GList *lnk_txn;
 	{
 	Account *acc = lnk_acc->data;
 	
-		//#1674045 ony rely on nosummary
+		//#1674045 only rely on nosummary
 		//if( !(acc->flags & AF_CLOSED) )
 		{
 		Transaction *txn;
@@ -222,10 +221,14 @@ GList *lnk_txn;
 	}
 	
 	if( flt->mindate == 0 )
-		flt->mindate = HB_MINDATE;
+		//changed 5.3
+		//flt->mindate = HB_MINDATE;
+		flt->mindate = GLOBALS->today - 365;
 	
 	if( flt->maxdate == 0 )
-		flt->maxdate = HB_MAXDATE;	
+		//changed 5.3
+		//flt->maxdate = HB_MAXDATE;
+		flt->maxdate = GLOBALS->today + flt->nbdaysfuture;
 	
 	g_list_free(lst_acc);
 }
@@ -234,6 +237,8 @@ GList *lnk_txn;
 void filter_preset_daterange_add_futuregap(Filter *filter, gint nbdays)
 {
 
+	DB( g_print("\n[filter] range add future gap\n") );
+	
 	//fixed > 5.1.7
 	/*if( nbdays <= 0 )
 	{
@@ -264,7 +269,7 @@ GDate *tmpdate;
 guint32 jtoday, jfiscal;
 guint16 month, year, yfiscal, qnum;
 
-	DB( g_print("\n(filter) daterange set %p %d\n", flt, range) );
+	DB( g_print("\n[filter] daterange set %p %d\n", flt, range) );
 
 	flt->range = range;
 	
@@ -365,6 +370,8 @@ guint16 month, year, yfiscal, qnum;
 void filter_preset_type_set(Filter *flt, gint type)
 {
 
+	DB( g_print("\n[filter] preset type set\n") );
+	
 	/* any type */
 	flt->type = type;
 	flt->option[FILTER_AMOUNT] = 0;
@@ -391,35 +398,27 @@ void filter_preset_type_set(Filter *flt, gint type)
 
 void filter_preset_status_set(Filter *flt, gint status)
 {
-Category *catitem;
-GList *lcat, *list;
 
+	DB( g_print("\n[filter] preset status set\n") );
+	
 	/* any status */
 	flt->status = status;
 	flt->option[FILTER_STATUS] = 0;
+	flt->option[FILTER_CATEGORY] = 0;
+	flt->option[FILTER_PAYMODE] = 0;
 	flt->reconciled = TRUE;
 	flt->cleared  = TRUE;
 	//#1602835 fautly set
 	//flt->forceadd = TRUE;
 	//flt->forcechg = TRUE;
 
-	flt->option[FILTER_CATEGORY] = 0;
-	lcat = list = g_hash_table_get_values(GLOBALS->h_cat);
-	while (list != NULL)
-	{
-		catitem = list->data;
-		catitem->flt_select = FALSE;
-		list = g_list_next(list);
-	}
-	g_list_free(lcat);
-
 	switch( status )
 	{
 		case FLT_STATUS_UNCATEGORIZED:
 			flt->option[FILTER_CATEGORY] = 1;
-			catitem = da_cat_get(0);	// no category
-			if(catitem != NULL)
-				catitem->flt_select = TRUE;
+			filter_status_cat_clear_except(flt, 0);
+			flt->option[FILTER_PAYMODE] = 1;
+			flt->paymode[PAYMODE_INTXFER] = FALSE;
 			break;
 
 		case FLT_STATUS_UNRECONCILED:
@@ -450,6 +449,38 @@ GList *lcat, *list;
 }
 
 
+gchar *filter_daterange_text_get(Filter *flt)
+{
+gchar buffer1[128];
+gchar buffer2[128];
+gchar buffer3[128];
+GDate *date;
+gchar *retval = NULL;
+
+	DB( g_print("\n[filter] daterange text get\n") );
+	
+	date = g_date_new_julian(flt->mindate);
+	g_date_strftime (buffer1, 128-1, PREFS->date_format, date);
+	
+	g_date_set_julian(date, flt->maxdate);
+	g_date_strftime (buffer2, 128-1, PREFS->date_format, date);
+	
+	if( flt->nbdaysfuture > 0 )
+	{
+		g_date_set_julian(date, flt->maxdate + flt->nbdaysfuture);
+		g_date_strftime (buffer3, 128-1, PREFS->date_format, date);
+		retval = g_strdup_printf("%s — <s>%s</s> %s", buffer1, buffer2, buffer3);
+	}
+	else
+		retval = g_strdup_printf("%s — %s", buffer1, buffer2);
+	
+	g_date_free(date);
+
+	//return g_strdup_printf(_("<i>from</i> %s <i>to</i> %s — "), buffer1, buffer2);
+	return retval;
+}
+
+
 /* used for quicksearch text into transaction */
 gboolean filter_txn_search_match(gchar *needle, Transaction *txn, gint flags)
 {
@@ -458,6 +489,8 @@ Payee *payitem;
 Category *catitem;
 gchar *tags;
 
+	DB( g_print("\n[filter] tnx search match\n") );
+	
 	if(flags & FLT_QSEARCH_MEMO)
 	{
 		//#1668036 always try match on txn memo first
@@ -569,14 +602,14 @@ end:
 }
 
 
-gint filter_test(Filter *flt, Transaction *txn)
+gint filter_txn_match(Filter *flt, Transaction *txn)
 {
 Account *accitem;
 Payee *payitem;
 Category *catitem;
 gint insert;
 
-	//DB( g_print("(filter) test\n") );
+	//DB( g_print("\n[filter] txn match\n") );
 
 	insert = 1;
 
