@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -61,7 +61,7 @@ da_import_context_gen_acc_destroy(ImportContext *context)
 {
 GList *list;
 
-	DB( g_print(" free gen acc list\n") );
+	DB( g_print("\n[import] free gen acc list\n") );
 	list = g_list_first(context->gen_lst_acc);
 	while (list != NULL)
 	{
@@ -304,44 +304,55 @@ GList *list;
 Account *
 hb_import_acc_find_existing(gchar *name, gchar *number)
 {
-Account *retacc;
+Account *retacc = NULL;
 GList *lacc, *list;
 
 	DB( g_print("\n[import] acc_find_existing\n") );
-	DB( g_print(" - search for '%s' or '%s'\n", name, number) );
 
-	retacc = NULL;
+	DB( g_print(" - search number '%s'\n", number) );
 	lacc = list = g_hash_table_get_values(GLOBALS->h_acc);
 	while (list != NULL)
 	{
 	Account *acc = list->data;
 		
-		DB( g_print(" - acc '%s' or '%s'\n", acc->name, acc->number) );
-		
+		//DB( g_print(" - eval acc '%s' or '%s'\n", acc->name, acc->number) );
 		if(number != NULL && acc->number && strlen(acc->number) )
 		{
 			//prefer identifying with number & search number into acc->number
 			if(g_strstr_len(number, -1, acc->number) != NULL)
 			{
-				DB( g_print(" - found '%s'\n", acc->number) );
+				DB( g_print(" - match number '%s'\n", acc->number) );
 				retacc = acc;
 				break;
 			}
 		}
-
-		//but if not found try with name	
-		if(retacc == NULL && name != NULL)
-		{
-			if(g_strstr_len(name, -1, acc->name) != NULL)
-			{
-				DB( g_print(" - found '%s'\n", acc->name) );
-				retacc = acc;
-				break;
-			}
-		}
-
 		list = g_list_next(list);
 	}
+
+	//# 1815964 only test name if all number test failed
+	//if not found try with name	
+	if(retacc == NULL)
+	{
+		DB( g_print(" - search name '%s'\n", name) );
+		list = g_list_first(lacc);
+		while (list != NULL)
+		{
+		Account *acc = list->data;
+			
+			//DB( g_print(" - eval acc '%s' or '%s'\n", acc->name, acc->number) );
+			if(retacc == NULL && name != NULL)
+			{
+				if(g_strstr_len(name, -1, acc->name) != NULL)
+				{
+					DB( g_print(" - match name '%s'\n", acc->name) );
+					retacc = acc;
+					break;
+				}
+			}
+			list = g_list_next(list);
+		}
+	}
+
 	g_list_free(lacc);
 
 	return retacc;
@@ -353,7 +364,7 @@ hb_import_gen_acc_get_next(ImportContext *ictx, gint filetype, gchar *name, gcha
 {
 GenAcc *newacc;
 
-	DB( g_print("\n[Import] acc_get_next\n") );
+	DB( g_print("\n[import] acc_get_next\n") );
 
 	DB( g_print(" - type='%d', name='%s', number='%s'\n", filetype, name, number) );
 
@@ -584,7 +595,7 @@ hb_import_load_all(ImportContext *ictx)
 {
 GList *list;
 
-	DB( g_print("\n[ui-import] load all\n") );
+	DB( g_print("\n[import] load all\n") );
 
 	da_import_context_clear (ictx);
 	
@@ -809,67 +820,78 @@ GList *match = NULL;
 gint count = 0;
 
 	DB( g_print("\n[import] gen xfer eval\n") );
-
 	
 	root = list1 = g_list_first(list);
 	while (list1 != NULL)
 	{
-	Transaction *gtxn1 = list1->data;
+	Transaction *txn1 = list1->data;
 	GenAcc *acc;
 
-		acc = da_gen_acc_get_by_key(ictx->gen_lst_acc, gtxn1->kacc);
+		acc = da_gen_acc_get_by_key(ictx->gen_lst_acc, txn1->kacc);
+
+		DB( g_print(" src: kacc:%d dat:%d amt:%.2f %s kfxacc:%d\n", txn1->kacc, txn1->date, txn1->amount, txn1->memo, txn1->kxferacc) );
+
 		if( (acc != NULL) && (acc->filetype == FILETYPE_OFX) )
 		{
-			g_list_free(match);
 			match = NULL;
 			count = 0;
 			list2 = g_list_next(root);
 			while (list2 != NULL)
 			{
-			Transaction *gentxn2 = list2->data;
+			Transaction *txn2 = list2->data;
 
-				if( (gentxn2->date > gtxn1->date) )
+				//DB( g_print(" -- chk: kacc:%d dat:%d amt:%.2f %s\n", txn2->kacc, txn2->date, txn2->amount, txn2->memo) );
+				if( (txn2->date > txn1->date) )
 					break;
 
-				if(gentxn2 == gtxn1)
+				if( (txn2 == txn1) || (txn2->paymode == PAYMODE_INTXFER) )
 					goto next;
 
 				//todo: maybe reinforce controls here
-				if( (gentxn2->kacc != gtxn1->kacc) 
-					&& (gentxn2->date == gtxn1->date)
-					&& (gentxn2->amount == -gtxn1->amount)
-					&& (hb_string_compare(gentxn2->memo, gtxn1->memo) == 0)
+				if( (txn2->kacc != txn1->kacc) 
+					&& (txn2->date == txn1->date)
+					&& (txn2->amount == -txn1->amount)
+					&& (hb_string_compare(txn2->memo, txn1->memo) == 0)
 				  )
 				{
-					DB( g_print(" found xfer?  %d=%d %.2f %.2f\n", gtxn1->date, gentxn2->date, gtxn1->amount, gentxn2->amount) );
-					match = g_list_append(match, gentxn2);
+					DB( g_print("  match: kacc:%d dat:%d amt:%.2f %s kfxacc:%d\n", txn2->kacc, txn2->date, txn2->amount, txn2->memo, txn2->kxferacc) );
+					match = g_list_append(match, txn2);
 					count++;
 				}
 			next:
 				list2 = g_list_next(list2);
 			}
+		
+			if(count == 1)  //we found a single potential xfer, transform it
+			{
+			Transaction *txn2 ;
+
+				DB( g_print("  single found => convert both\n") );
+
+				list2 = g_list_first(match);	
+				txn2 = list2->data;
+
+				
+				txn1->paymode = PAYMODE_INTXFER;
+				transaction_xfer_change_to_child(txn1, txn2);
+				
+				/*list2 = g_list_first(match);	
+				txn2 = list2->data;
+				
+				txn1->paymode = PAYMODE_INTXFER;
+				txn1->kxferacc = txn2->kacc;
+				
+				txn2->paymode = PAYMODE_INTXFER;
+				txn2->kxferacc = txn1->kacc;
+				*/
+			}
+			// if more than one, we cannot be sure
+			g_list_free(match);
 		}
-		
-		if(count == 1)  //we found a single potential xfer, transform it
-		{
-		Transaction *gentxn2 ;
-		
-			list2 = g_list_first(match);	
-			gentxn2 = list2->data;
-			
-			gtxn1->paymode = PAYMODE_INTXFER;
-			gtxn1->kxferacc = gentxn2->kacc;
-			
-			gentxn2->paymode = PAYMODE_INTXFER;
-			gentxn2->kxferacc = gtxn1->kacc;
-		}
-		// if more than one, we cannot be sure
-		
+
 		list1 = g_list_next(list1);
 	}
 	
-	g_list_free(match);
-	
 	return count;
 }
 
@@ -919,13 +941,21 @@ GList *list;
 				// OFX:check_number
 				gentxn->info = g_strdup(gentxn->rawinfo);
 
-				if(ictx->opt_ofxname == 2)
-					gentxn->payee = g_strdup(gentxn->rawpayee);
-				else if(ictx->opt_ofxname == 1)
-					gentxn->memo = g_strdup(gentxn->rawpayee);
-
-				DB( g_print(" - payee is '%s'\n", gentxn->payee) );
-				DB( g_print(" - memo is '%s'\n", gentxn->memo) );
+				//#1791482 map name to info (concat only)
+				switch(ictx->opt_ofxname)
+				{
+					//ofxname is stored into rawpayee
+					case 1:
+						gentxn->memo = g_strdup(gentxn->rawpayee);
+						break;
+					case 2:
+						gentxn->payee = g_strdup(gentxn->rawpayee);
+						break;
+					case 3:
+						g_free(gentxn->info);
+						gentxn->info = _string_concat(gentxn->rawinfo, gentxn->rawpayee);
+						break;
+				}
 
 				if(gentxn->rawmemo != NULL)
 				{
@@ -946,6 +976,9 @@ GList *list;
 					}
 				}
 
+				DB( g_print(" - payee is '%s'\n", gentxn->payee) );
+				DB( g_print(" - memo is '%s'\n", gentxn->memo) );
+				DB( g_print(" - info is '%s'\n", gentxn->info) );
 				DB( g_print("\n") );
 
 			}
@@ -1163,54 +1196,16 @@ gint nsplit;
 		else
 		if( gentxn->cleared )
 			newope->status = TXN_STATUS_CLEARED;
-		
-
-
-
 	}
 	return newope;
 }
 
-//todo: chck if not redundant with some hb_trasaciton.c fucntion
-//it is :same than transaction_old_get_child_transfer
-static Transaction *
-hb_import_xfer_child_search(Transaction *src, GList *list)
-{
-	DB( g_print("([import] xfer_child_search\n") );
-
-	DB( g_print(" search: %d %s %f %d=>%d\n", src->date, src->memo, src->amount, src->kacc, src->kxferacc) );
-
-	list = g_list_first(list);
-	while (list != NULL)
-	{
-	Transaction *item = list->data;
-	
-		if( item->paymode == PAYMODE_INTXFER)
-		{
-			if( src->date == item->date &&
-			    src->kacc == item->kxferacc &&
-			    src->kxferacc == item->kacc &&
-			    ABS(src->amount) == ABS(item->amount) )
-			{
-				DB( g_print(" found : %d %s %f %d=>%d\n", item->date, item->memo, item->amount, item->kacc, item->kxferacc) );
-
-				return item;
-			}
-		}
-		list = g_list_next(list);
-	}
-
-	DB( g_print(" not found...\n") );
-
-	return NULL;
-}
-
 
 void 
 hb_import_apply(ImportContext *ictx)
 {
 GList *list, *lacc;
-GList *txnlist = NULL;
+GList *txnlist;
 guint32 kcommon = 0;
 guint changes = 0;
 
@@ -1222,7 +1217,7 @@ guint changes = 0;
 	{
 	GenAcc *genacc = list->data;
 
-		DB( g_print(" - genacc: %d %s %s => %d\n", genacc->key, genacc->name, genacc->number, genacc->kacc) );
+		DB( g_print(" #1 genacc: %d %s %s => %d\n", genacc->key, genacc->name, genacc->number, genacc->kacc) );
 
 		//we do create the common account once
 		if( (genacc->kacc == DST_ACC_GLOBAL) )
@@ -1263,6 +1258,9 @@ guint changes = 0;
 
 	// insert every transactions into a temporary list
 	// we do this to keep a finished real txn list for detect xfer below
+	DB( g_print(" #2 insert txn\n") );
+
+	txnlist = NULL;
 	lacc = g_list_first(ictx->gen_lst_acc);
 	while (lacc != NULL)
 	{
@@ -1277,105 +1275,39 @@ guint changes = 0;
 
 				if(gentxn->kacc == genacc->key && gentxn->to_import == TRUE)
 				{
-				Transaction *txn;
+				Transaction *txn, *dtxn;
 		
 					txn = hb_import_convert_txn(genacc, gentxn);
 					if( txn )
 					{
-						txnlist = g_list_append(txnlist, txn);					
+						dtxn = transaction_add(NULL, txn);
+						txnlist = g_list_append(txnlist, dtxn);					
+						da_transaction_free(txn);
+						//#1820618 forgot to report changes count
+						changes++;
 					}
 				}
 				list = g_list_next(list);
 			}
-		
 		}
 		lacc = g_list_next(lacc);
 	}
 
+	//auto assign
+	DB( g_print(" call auto assign\n") );
+	transaction_auto_assign(txnlist, 0);
+	
 	//check for ofx internal xfer
 	DB( g_print(" call hb_import_gen_xfer_eval\n") );
 	hb_import_gen_xfer_eval(ictx, txnlist);
 
-	//auto assign
-	DB( g_print(" call auto assign\n") );
-	transaction_auto_assign(txnlist, 0);
-
-	// last: insert transaction for real
-	DB( g_print(" real import txn\n") );
-
-	list = g_list_first(txnlist);	
-	while (list != NULL)
-	{
-	Transaction *txn = list->data;
-	Transaction *child;
-
-		//avoid adding a child xfer
-		child = hb_import_xfer_child_search(txn, txnlist);
-		if( child != NULL)
-		{
-			DB( g_print(" -> transaction already exist\n" ) );
-			da_transaction_free(txn);
-		}
-		else
-		{
-			transaction_add(NULL, txn);
-			da_transaction_free(txn);
-			changes++;
-		}
-		list = g_list_next(list);
-	}
-	
 	g_list_free(txnlist);
 
 	GLOBALS->changes_count += changes;
 	
-	/*
-	// transform our qif transactions to homebank ones
-	qiflist = g_list_first(ictx->gen_lst_txn);
-	while (qiflist != NULL)
-	{
-	GenTxn *item = qiflist->data;
-	Transaction *newope;
-	Account *accitem;
-	Category *catitem;
-	gint nsplit;
-
-		//moved was here
-
-
-
-		// account + append
-		//todo: commented
-		//name = strcmp(QIF_UNKNOWN_ACCOUNT_NAME, item->account) == 0 ? "" : item->account;
-
-		//todo: diabeldd and commented tinto hb-import
-		//accitem = import_create_account(name, NULL);
-
-		//newope->kacc = accitem->key;
-
-		
-		//todo: rework this
-
-		child = account_qif_get_child_transfer(newope, list);
-		if( child != NULL)
-		{
-			//DB( g_print(" -> transaction already exist\n" ) );
-
-			da_transaction_free(newope);
-		}
-		else
-		{
-			//DB( g_print(" -> append trans. acc:'%s', memo:'%s', val:%.2f\n", item->account, item->memo, item->amount ) );
-
-			list = g_list_append(list, newope);
-
-		qiflist = g_list_next(qiflist);
-	}
-
-	*/
-
 }
 
+
 #if MYDEBUG
 void _import_context_debug_file_list(ImportContext *ctx)
 {
@@ -1434,258 +1366,3 @@ GList *list;
 
 #endif
 
-
-
-/*Account *import_create_account(gchar *name, gchar *number)
-{
-Account *accitem, *existitem;
-
-	//first check we do not have already this imported account
-	existitem = da_acc_get_by_imp_name(name);
-	if(existitem != NULL)
-		return existitem;
-
-	accitem = da_acc_malloc();
-	accitem->key  = da_acc_get_max_key() + 1;
-	accitem->pos  = da_acc_length() + 1;
-
-	// existing named account ?
-	existitem = da_acc_get_by_name(name);
-	if(existitem != NULL)
-		accitem->imp_key = existitem->key;
-
-	if(!existitem && *name != 0)
-			accitem->name = g_strdup(name);
-	else
-		
-		accitem->name = g_strdup_printf(_("(account %d)"), accitem->key);
-
-	accitem->imp_name = g_strdup(name);
-
-	if(number)
-		accitem->number = g_strdup(number);
-
-	accitem->imported = TRUE;
-	da_acc_insert(accitem);
-
-	return accitem;
-}
-*/
-
-
-/*
-TODO: should move or be rewritten
-the goal is to find already existing txn into real transaction
-quesiotn is: is it possible at this stgae ??
-rewritten into hb-transaction
-
-static gboolean ui_import_page_transaction_is_duplicate(Transaction *impope, Transaction *ope, gint maxgap)
-{
-Account *dstacc;
-guint dstkacc;
-gboolean retval = FALSE;
-
-	//common tests
-	if( (impope->amount == ope->amount) &&
-		(ope->date <= (impope->date + maxgap)) && (ope->date >= (impope->date - maxgap)) )
-	{
-
-		//we focus the test on impope->acc->imp_key (and not impope->kacc)
-		dstkacc = impope->kacc; 
-		dstacc = da_acc_get(dstkacc);
-
-
-		DB( g_print("--------\n -> dstkacc=%d, amount & date are similar\n", dstkacc) );
-
-		DB( g_print(" -> impope: kacc=%d, %s kxfer=%d, kxferacc=%d\n", impope->kacc, impope->memo, impope->kxfer, impope->kxferacc) );
-		DB( g_print(" ->    ope: kacc=%d, %s kxfer=%d, kxferacc=%d\n", ope->kacc, ope->memo, ope->kxfer, ope->kxferacc) );
-
-
-		if(impope->paymode != PAYMODE_INTXFER)
-		{
-			if( dstkacc == ope->kacc )
-			{
-				DB( g_print(" -> impope is not a xfer and acc are similar\n") );
-				retval = TRUE;
-			}
-		}
-		else
-		{
-			if( ( (impope->kxferacc == ope->kxferacc) && ope->kxfer != 0) ||
-				( impope->kxferacc == 0 )
-			   )
-				retval = TRUE;
-		}
-	}
-	return retval;
-}
-
-
-static void ui_import_page_transaction_find_duplicate(struct import_data *data)
-{
-ImportContext *ictx = &data->ictx;
-GList *tmplist, *implist;
-Transaction *item;
-guint32 mindate;
-guint maxgap;
-
-	DB( g_print("\n[ui-import] find duplicate\n") );
-
-	ictx->nb_duplicate = 0;
-	if( ictx->trans_list )
-	{
-		// 1: get import min bound date
-		tmplist = g_list_first(ictx->trans_list);
-		item = tmplist->data;
-		mindate = item->date;
-		maxgap = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_maxgap));
-
-		// clear any previous same txn
-		implist = g_list_first(ictx->trans_list);
-		while (implist != NULL)
-		{
-		Transaction *impope = implist->data;
-
-			if(impope->same != NULL)
-			{
-				g_list_free(impope->same);
-				impope->same = NULL;
-			}
-			implist = g_list_next(implist);
-		}
-		
-		tmplist = g_list_first(old txn list);
-		while (tmplist != NULL)
-		{
-		Transaction *ope = tmplist->data;
-
-			if( ope->date >= mindate )
-			{
-				//DB( g_print("should check here %d: %s\n", ope->date, ope->memo) );
-
-				implist = g_list_first(ictx->trans_list);
-				while (implist != NULL)
-				{
-				Transaction *impope = implist->data;
-
-					if( ui_import_page_transaction_is_duplicate(impope, ope, maxgap) )
-					{
-						//DB( g_print(" found %d: %s\n", impope->date, impope->memo) );
-
-						impope->same = g_list_append(impope->same, ope);
-						ictx->nb_duplicate++;
-					}
-
-					implist = g_list_next(implist);
-				}
-			}
-
-			tmplist = g_list_next(tmplist);
-		}
-	}
-
-	DB( g_print(" nb_duplicate = %d\n", ictx->nb_duplicate) );
-}
-*/
-
-
-/*
-static Transaction *
-account_qif_get_child_transfer(Transaction *src, GList *list)
-{
-Transaction *item;
-
-	DB( g_print("([qif] get_child_transfer\n") );
-
-	//DB( g_print(" search: %d %s %f %d=>%d\n", src->date, src->memo, src->amount, src->account, src->kxferacc) );
-
-	list = g_list_first(list);
-	while (list != NULL)
-	{
-		item = list->data;
-		if( item->paymode == PAYMODE_INTXFER)
-		{
-			if( src->date == item->date &&
-			    src->kacc == item->kxferacc &&
-			    src->kxferacc == item->kacc &&
-			    ABS(src->amount) == ABS(item->amount) )
-			{
-				//DB( g_print(" found : %d %s %f %d=>%d\n", item->date, item->memo, item->amount, item->account, item->kxferacc) );
-
-				return item;
-			}
-		}
-		list = g_list_next(list);
-	}
-
-	//DB( g_print(" not found...\n") );
-
-	return NULL;
-}
-*/
-
-
-/*
-** convert after userr say ok (apply)
-
-GList *
-account_import_qif(gchar *filename, ImportContext *ictx)
-{
-GList *qiflist;
-GList *list = NULL;
-
-	// check iso date format in file
-	//isodate = hb_qif_parser_check_iso_date(&ctx);
-	//DB( g_print(" -> date is dd/mm/yy: %d\n", isodate) );
-
-	DB( g_print("\n[import] real import\n") );
-
-	DB( g_print(" -> %d qif txn\n",  g_list_length(ictx->gen_lst_txn)) );
-
-	// transform our qif transactions to homebank ones
-	qiflist = g_list_first(ictx->gen_lst_txn);
-	while (qiflist != NULL)
-	{
-	GenTxn *item = qiflist->data;
-	Transaction *newope;
-	Account *accitem;
-	Category *catitem;
-	gint nsplit;
-
-		//moved was here
-
-
-
-		// account + append
-		//todo: commented
-		//name = strcmp(QIF_UNKNOWN_ACCOUNT_NAME, item->account) == 0 ? "" : item->account;
-
-		//todo: diabeldd and commented tinto hb-import
-		//accitem = import_create_account(name, NULL);
-
-		//newope->kacc = accitem->key;
-
-		
-		//todo: rework this
-
-		child = account_qif_get_child_transfer(newope, list);
-		if( child != NULL)
-		{
-			//DB( g_print(" -> transaction already exist\n" ) );
-
-			da_transaction_free(newope);
-		}
-		else
-		{
-			//DB( g_print(" -> append trans. acc:'%s', memo:'%s', val:%.2f\n", item->account, item->memo, item->amount ) );
-
-			list = g_list_append(list, newope);
-
-		qiflist = g_list_next(qiflist);
-	}
-
-	DB( g_print(" -> %d txn converted\n", g_list_length(list)) );
-	
-	return list;
-}
-*/
