@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -282,6 +282,9 @@ da_pay_get(guint32 key)
 void da_pay_consistency(Payee *item)
 {
 	g_strstrip(item->name);
+	//5.2.4 we drop internal xfer here as it will disapear 
+	if( item->paymode == PAYMODE_INTXFER )
+		item->paymode = PAYMODE_XFER;
 }
 
 
