@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -289,6 +289,7 @@ void homebank_pref_free(void)
 
 	g_free(PREFS->language);
 
+	g_free(PREFS->pnl_list_tab);
 
 	g_free(PREFS->minor_cur.symbol);
 	g_free(PREFS->minor_cur.decimal_char);
@@ -606,6 +607,7 @@ GKeyFile *keyfile;
 gboolean retval = FALSE;
 gchar *group, *filename;
 guint32 version;
+gboolean loaded;
 GError *error = NULL;
 
 	DB( g_print("\n[preferences] pref load\n") );
@@ -617,8 +619,15 @@ GError *error = NULL;
 
 		DB( g_print(" - filename: %s\n", filename) );
 
-
-		if(g_key_file_load_from_file (keyfile, filename, G_KEY_FILE_NONE, NULL))
+		error = NULL;
+		loaded = g_key_file_load_from_file (keyfile, filename, G_KEY_FILE_NONE, &error);
+		if( error )
+		{
+			g_warning("unable to load file %s: %s", filename, error->message);
+			g_error_free (error);
+		}
+			
+		if( loaded == TRUE )
 		{
 
 			group = "General";
@@ -712,7 +721,7 @@ GError *error = NULL;
 
 					if(version <= 2)	//retrieve old 0.1 or 0.2 visibility boolean
 					{
-						bsrc = g_key_file_get_boolean_list(keyfile, group, "ColumnsOpe", &length, &error);
+						bsrc = g_key_file_get_boolean_list(keyfile, group, "ColumnsOpe", &length, NULL);
 						if( length == NUM_LST_DSPOPE-1 )
 						{
 							//and convert
@@ -725,7 +734,7 @@ GError *error = NULL;
 					}
 					else
 					{
-						src = g_key_file_get_integer_list(keyfile, group, "ColumnsOpe", &length, &error);
+						src = g_key_file_get_integer_list(keyfile, group, "ColumnsOpe", &length, NULL);
 
 						DB( g_print(" - length %d (max=%d)\n", length, NUM_LST_DSPOPE) );
 
@@ -782,7 +791,7 @@ GError *error = NULL;
 				gint *src;
 				gsize length;
 
-					src = g_key_file_get_integer_list(keyfile, group, "ColumnsOpeWidth", &length, &error);
+					src = g_key_file_get_integer_list(keyfile, group, "ColumnsOpeWidth", &length, NULL);
 
 					DB( g_print(" - length %d (max=%d)\n", length, NUM_LST_DSPOPE) );
 
@@ -848,6 +857,7 @@ GError *error = NULL;
 				homebank_pref_get_short(keyfile, group, "UpcColPayW", &PREFS->pnl_upc_col_pay_width);
 				homebank_pref_get_short(keyfile, group, "UpcColMemW", &PREFS->pnl_upc_col_mem_width);
 
+				homebank_pref_get_string(keyfile, group, "PnlLstTab", &PREFS->pnl_list_tab);
 
 			group = "Format";
 
@@ -990,6 +1000,7 @@ GError *error = NULL;
 	return retval;
 }
 
+
 static void homebank_pref_set_string(
 	GKeyFile *key_file,
     const gchar *group_name,
@@ -1016,6 +1027,7 @@ GKeyFile *keyfile;
 gboolean retval = FALSE;
 gchar *group, *filename;
 gsize length;
+GError *error = NULL;
 
 	DB( g_print("\n[preferences] pref save\n") );
 
@@ -1100,6 +1112,7 @@ gsize length;
 		g_key_file_set_integer(keyfile, group, "UpcColPayW", PREFS->pnl_upc_col_pay_width);
 		g_key_file_set_integer(keyfile, group, "UpcColMemW", PREFS->pnl_upc_col_mem_width);
 
+		homebank_pref_set_string  (keyfile, group, "PnlLstTab", PREFS->pnl_list_tab);
 
 		DB( g_print(" -> ** format\n") );
 
@@ -1178,8 +1191,14 @@ gsize length;
 
 		DB( g_print(" -> filename: %s\n", filename) );
 
-		g_file_set_contents(filename, contents, length, NULL);
-
+		g_file_set_contents(filename, contents, length, &error);
+		if( error )
+		{
+			g_warning("unable to save file %s: %s", filename, error->message);
+			g_error_free (error);
+			error = NULL;
+		}
+		
 		DB( g_print(" -> contents: %s\n", contents) );
 
 		DB( g_print(" -> freeing filename\n") );
