@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -463,7 +463,7 @@ guint nbsplit;
 	}
 
 	//#1628678 tags for internal xfer should be checked as well
-
+	//#1787826 intxfer should not have split
 
 	//#1295877 ensure income flag is correctly set
 	item->flags &= ~(OF_INCOME);
@@ -646,13 +646,20 @@ gint count;
 
 		default:	//the user must choose himself
 		{
+		gint result;
 		Transaction *child;
 
-			child = ui_dialog_transaction_xfer_select_child(parent, ope, matchlist);
-			if(child == NULL)
-				transaction_xfer_create_child(ope);
-			else
+			result = ui_dialog_transaction_xfer_select_child(parent, ope, matchlist, &child);
+			if( result == GTK_RESPONSE_ACCEPT )
+			{
 				transaction_xfer_change_to_child(ope, child);
+			}
+			else //GTK_RESPONSE_CANCEL
+			{
+				ope->paymode = PAYMODE_NONE;
+				ope->kxfer = 0;
+				ope->kxferacc = 0;
+			}
 		}
 	}
 
