@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -614,7 +614,7 @@ gint i;
 }
 
 
-static void homebank_load_xml_tag(ParseContext *ctx, const gchar **attribute_names, const gchar **attribute_values)
+/*static void homebank_load_xml_tag(ParseContext *ctx, const gchar **attribute_names, const gchar **attribute_values)
 {
 Tag *entry = da_tag_malloc();
 gint i;
@@ -630,7 +630,7 @@ gint i;
 
 	//all attribute loaded: append
 	da_tag_insert(entry);
-}
+}*/
 
 
 static void homebank_load_xml_fav(ParseContext *ctx, const gchar **attribute_names, const gchar **attribute_values)
@@ -759,7 +759,7 @@ start_element_handler (GMarkupParseContext *context,
 ParseContext *ctx = user_data;
 //GtkUIManager *self = ctx->self;
 
-	//DB( g_print("** start element: %s\n", element_name) );
+	//DB( g_print("** start element: '%s'\n", element_name) );
 
 	switch(element_name[0])
 	{
@@ -789,6 +789,15 @@ ParseContext *ctx = user_data;
 		}
 		break;
 
+
+
+
+
+
+
+
+
+
 		case 'c':
 		{
 			if(!strcmp (element_name, "cat"))
@@ -802,14 +811,16 @@ ParseContext *ctx = user_data;
 		}
 		break;
 
-		case 't':
+		//TODO: < 5.2 misstyped here, should be tag without a s
+		//commented > 5.2 useless not loaded, but no side effect
+		/*case 't':
 		{
 			if(!strcmp (element_name, "tags"))
 			{
 				homebank_load_xml_tag(ctx, attribute_names, attribute_values);
 			}
 		}
-		break;
+		break;*/
 
 		case 'f':
 		{
@@ -905,9 +916,12 @@ gboolean rc;
 	retval = XML_OK;
 	if (!g_file_get_contents (filename, &buffer, &length, &error))
 	{
-		//g_message ("%s", error->message);
-		retval = XML_IO_ERROR;
-		g_error_free (error);
+		if(error)
+		{
+			g_warning("unable to load file %s: %s", filename, error->message);
+			g_error_free(error);
+			retval = XML_IO_ERROR;
+		}
 	}
 	else
 	{
@@ -941,15 +955,22 @@ gboolean rc;
 			rc = g_markup_parse_context_parse (context, buffer, length, &error);
 
 			if( error )
+			{
 				g_print("failed: %s\n", error->message);
+				g_error_free (error);
+			}
 
+				
 			if( rc == FALSE )
 			{
 				error = NULL;
 				g_markup_parse_context_end_parse(context, &error);
 
 				if( error )
+				{
 					g_print("failed: %s\n", error->message);
+					g_error_free (error);
+				}
 			}
 
 			g_markup_parse_context_free (context);
@@ -1021,6 +1042,10 @@ gboolean rc;
 				hbfile_sanity_check();
 				homebank_upgrade_to_v13();
 			}
+			if( ctx.data_version <= 50203 )
+			{
+				hbfile_sanity_check();
+			}
 
 			// next ?
 			
@@ -1260,6 +1285,7 @@ GError *error = NULL;
 		hb_xml_append_txt_crlf(node, "notes", item->notes);
 		hb_xml_append_int(node, "tpl", item->karc);
 
+
 		g_string_append(node, "/>\n");
 
 		error = NULL;
@@ -1381,7 +1407,7 @@ GError *error = NULL;
 /*
 ** XML tag save
 */
-static gint homebank_save_xml_tag(GIOChannel *io)
+/*static gint homebank_save_xml_tag(GIOChannel *io)
 {
 GList *ltag, *list;
 gchar *tmpstr;
@@ -1414,7 +1440,7 @@ GError *error = NULL;
 	}
 	g_list_free(ltag);
 	return retval;
-}
+}*/
 
 
 /*
@@ -1639,38 +1665,34 @@ gint retval = XML_OK;
 GError *error = NULL;
 
 	io = g_io_channel_new_file(filename, "w", &error);
-	if(io == NULL)
+	if(error)
 	{
-		g_message("file error on: %s", filename);
-		retval = XML_IO_ERROR;
-		
-		if(error)
-			g_print("failed: %s\n", error->message);
-		
+		g_warning("unable to save file %s: %s", filename, error->message);
 		g_error_free(error);
+		return(XML_IO_ERROR);
 	}
-	else
-	{
-		g_io_channel_write_chars(io, "<?xml version=\"1.0\"?>\n", -1, NULL, NULL);
 
-		outstr = g_strdup_printf("<homebank v=\"%s\" d=\"%06d\">\n", g_ascii_dtostr (buf1, sizeof (buf1), FILE_VERSION), HB_VERSION_NUM);
-		g_io_channel_write_chars(io, outstr, -1, NULL, NULL);
-		g_free(outstr);
+	g_io_channel_write_chars(io, "<?xml version=\"1.0\"?>\n", -1, NULL, NULL);
 
-		retval = homebank_save_xml_prop(io);
-		retval = homebank_save_xml_cur(io);
-		retval = homebank_save_xml_acc(io);
-		retval = homebank_save_xml_pay(io);
-		retval = homebank_save_xml_cat(io);
-		retval = homebank_save_xml_tag(io);
-		retval = homebank_save_xml_asg(io);
-		retval = homebank_save_xml_arc(io);
-		retval = homebank_save_xml_ope(io);
+	outstr = g_strdup_printf("<homebank v=\"%s\" d=\"%06d\">\n", g_ascii_dtostr (buf1, sizeof (buf1), FILE_VERSION), HB_VERSION_NUM);
+	g_io_channel_write_chars(io, outstr, -1, NULL, NULL);
+	g_free(outstr);
 
-		g_io_channel_write_chars(io, "</homebank>\n", -1, NULL, NULL);
+	retval = homebank_save_xml_prop(io);
+	retval = homebank_save_xml_cur(io);
+	retval = homebank_save_xml_acc(io);
+	retval = homebank_save_xml_pay(io);
+	retval = homebank_save_xml_cat(io);
+	//retval = homebank_save_xml_tag(io);
+	retval = homebank_save_xml_asg(io);
+	retval = homebank_save_xml_arc(io);
+
+	retval = homebank_save_xml_ope(io);
+
+	g_io_channel_write_chars(io, "</homebank>\n", -1, NULL, NULL);
+
+	g_io_channel_unref (io);
 
-		g_io_channel_unref (io);
-	}
 	return retval;
 }
 
