@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -20,7 +20,7 @@
 
 #include "homebank.h"
 
-#include "dsp_mainwindow.h"
+#include "dsp-mainwindow.h"
 #include "hb-preferences.h"
 #include "language.h"
 
@@ -251,8 +251,10 @@ gboolean retval = FALSE;
 		retval = TRUE;
 	}
 	else
+	{
 		DB( g_print(" - cannot delete: '%s'\n", filepath) );
-
+	}
+	
 	return retval;
 }
 
@@ -400,6 +402,7 @@ gchar *homebank_lastopenedfiles_load(void)
 GKeyFile *keyfile;
 gchar *group, *filename, *tmpfilename;
 gchar *lastfilename = NULL;
+GError *error = NULL;
 
 	DB( g_print("\n[homebank] lastopenedfiles load\n") );
 
@@ -407,7 +410,7 @@ gchar *lastfilename = NULL;
 	if(keyfile)
 	{
 		filename = g_build_filename(homebank_app_get_config_dir(), "lastopenedfiles", NULL );
-		if(g_key_file_load_from_file (keyfile, filename, G_KEY_FILE_NONE, NULL))
+		if(g_key_file_load_from_file (keyfile, filename, G_KEY_FILE_NONE, &error))
 		{
 			group = "HomeBank";
 
@@ -421,6 +424,13 @@ gchar *lastfilename = NULL;
 				}
 			}
 		}
+
+		if( error )
+		{
+			g_print("failed: %s\n", error->message);
+			g_error_free (error);
+		}
+
 		g_free(filename);
 		g_key_file_free (keyfile);
 	}
@@ -438,6 +448,7 @@ GKeyFile *keyfile;
 gboolean retval = FALSE;
 gchar *group, *filename;
 gsize length;
+GError *error = NULL;
 
 	DB( g_print("\n[homebank] lastopenedfiles save\n") );
 
@@ -459,9 +470,16 @@ gsize length;
 				//DB( g_print(" keyfile:\n%s\nlen=%d\n", contents, length) );
 
 				filename = g_build_filename(homebank_app_get_config_dir(), "lastopenedfiles", NULL );
-				g_file_set_contents(filename, contents, length, NULL);
+
+				g_file_set_contents(filename, contents, length, &error);
 				g_free(filename);
 
+				if( error )
+				{
+					g_print("failed: %s\n", error->message);
+					g_error_free (error);
+				}
+				
 				g_free(contents);
 				g_key_file_free (keyfile);
 			}
