@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -35,16 +35,7 @@ extern struct HomeBank *GLOBALS;
 extern struct Preferences *PREFS;
 
 
-gchar *CYA_ACC_TYPE[] = 
-{
-	N_("(no type)"),
-	N_("Bank"),
-	N_("Cash"),
-	N_("Asset"),
-	N_("Credit card"),
-	N_("Liability"),
-	NULL
-};
+extern HbKvData CYA_ACC_TYPE[];
 
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
@@ -601,7 +592,7 @@ gint field = GPOINTER_TO_INT(user_data);
 		
 			case FIELD_BANK:
 				g_free(item->bankname);
-				item->bankname = g_strdup(gtk_entry_get_text(GTK_ENTRY(data->ST_bank)));
+				item->bankname = g_strdup(gtk_entry_get_text(GTK_ENTRY(data->ST_institution)));
 				break;
 
 			case FIELD_NUMBER:
@@ -719,12 +710,12 @@ Account *item;
 	{	
 		data->change++;
 
-		item->type = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_type));
+		item->type = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_type));
 
 		account_set_currency(item, ui_cur_combobox_get_key(GTK_COMBO_BOX(data->CY_curr)) );
 
 		g_free(item->bankname);
-		item->bankname = g_strdup(gtk_entry_get_text(GTK_ENTRY(data->ST_bank)));
+		item->bankname = g_strdup(gtk_entry_get_text(GTK_ENTRY(data->ST_institution)));
 
 		g_free(item->number);
 		item->number = g_strdup(gtk_entry_get_text(GTK_ENTRY(data->ST_number)));
@@ -769,7 +760,7 @@ Account *item;
 		gtk_spin_button_update(GTK_SPIN_BUTTON(data->ST_cheque2));
 		item->cheque2 = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(data->ST_cheque2));
 
-		item->karc= hb_combo_box_get_active_id(GTK_COMBO_BOX(data->CY_template));
+		item->karc= hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_template));
 		//active_id = gtk_combo_box_get_active_id(GTK_COMBO_BOX(data->CY_template));
 		//item->karc = atoi(active_id);
 	}
@@ -823,14 +814,14 @@ Account *item;
 
 		DB( g_print(" -> set acc id=%d\n", item->key) );
 
-		gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_type), item->type );
+		hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_type), item->type );
 
 		ui_cur_combobox_set_active(GTK_COMBO_BOX(data->CY_curr), item->kcur);
 		
 		if(item->bankname != NULL)
-			gtk_entry_set_text(GTK_ENTRY(data->ST_bank), item->bankname);
+			gtk_entry_set_text(GTK_ENTRY(data->ST_institution), item->bankname);
 		else
-			gtk_entry_set_text(GTK_ENTRY(data->ST_bank), "");
+			gtk_entry_set_text(GTK_ENTRY(data->ST_institution), "");
 
 		if(item->number != NULL)
 			gtk_entry_set_text(GTK_ENTRY(data->ST_number), item->number);
@@ -856,7 +847,7 @@ Account *item;
 		gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_cheque1), item->cheque1);
 		gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_cheque2), item->cheque2);
 
-		hb_combo_box_set_active_id(GTK_COMBO_BOX(data->CY_template), item->karc);
+		hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_template), item->karc);
 		//g_snprintf(idbuffer, 11, "%d", item->karc);
 		//gtk_combo_box_set_active_id(GTK_COMBO_BOX(data->CY_template), idbuffer);
 
@@ -1223,7 +1214,6 @@ gboolean doupdate = FALSE;
 static void ui_acc_manage_setup(struct ui_acc_manage_data *data)
 {
 GList *tmplist;
-gchar idbuffer[12];
 
 	DB( g_print("\n(ui_acc_manage_setup)\n") );
 
@@ -1238,7 +1228,7 @@ gchar idbuffer[12];
 	//populate_view_acc(data->LV_acc, GLOBALS->acc_list, TRUE);
 
 	//populate template
-	gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(data->CY_template), "0", _("(none)"));
+	hbtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(data->CY_template), 0, _("(none)"));
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_template), 0);
 	tmplist = g_list_first(GLOBALS->arc_list);
 	while (tmplist != NULL)
@@ -1247,8 +1237,7 @@ gchar idbuffer[12];
 
 		if( !(item->flags & OF_AUTO) )
 		{
-			g_snprintf(idbuffer, 11, "%d", item->key);
-			gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(data->CY_template), idbuffer, item->memo);
+			hbtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(data->CY_template), item->key, item->memo);
 		}
 		tmplist = g_list_next(tmplist);
 	}
@@ -1359,7 +1348,8 @@ gint w, h, row;
 	row = 1;
 	label = make_label_widget(_("_Type:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-	widget = make_cycle(label, CYA_ACC_TYPE);
+	//widget = make_cycle(label, CYA_ACC_TYPE);
+	widget = hbtk_combo_box_new_with_data(label, CYA_ACC_TYPE);
 	data.CY_type = widget;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
@@ -1445,7 +1435,7 @@ gint w, h, row;
 	label = make_label_widget(_("_Name:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_string(label);
-	data.ST_bank = widget;
+	data.ST_institution = widget;
 	gtk_widget_set_hexpand(widget, TRUE);
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 2, 1);
 
@@ -1487,7 +1477,7 @@ gint w, h, row;
 	row = 1;
 	label = make_label_widget(_("Default _Template:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-	widget = gtk_combo_box_text_new();
+	widget = hbtk_combo_box_new(label);
 	data.CY_template = widget;
 	gtk_widget_set_hexpand(widget, TRUE);
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 2, 1);
