@@ -1,5 +1,5 @@
 /*	HomeBank -- Free, easy, personal accounting for everyone.
- *	Copyright (C) 1995-2018 Maxime DOYEN
+ *	Copyright (C) 1995-2019 Maxime DOYEN
  *
  *	This file is part of HomeBank.
  *
@@ -21,8 +21,8 @@
 
 #include "hb-import.h"
 #include "ui-assist-import.h"
-#include "dsp_mainwindow.h"
-#include "list_operation.h"
+#include "dsp-mainwindow.h"
+#include "list-operation.h"
 
 
 /****************************************************************************/
@@ -55,7 +55,7 @@ static void ui_import_page_filechooser_eval(GtkWidget *widget, gpointer user_dat
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
-#if MYDEBUG
+#if MYDEBUG == 1
 static void list_txn_cell_data_function_debug (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 GenTxn *gentxn;
@@ -136,7 +136,7 @@ GenTxn *item;
 
 	switch(colid)
 	{
-		case 1: //date
+		case LST_DSPOPE_DATE: //date
 			{
 			gchar *color = NULL;
 			
@@ -160,16 +160,13 @@ GenTxn *item;
 			}
 			//g_object_set(renderer, "text", item->date, NULL);
 			break;
-		case 2: //memo
+		case LST_DSPOPE_MEMO: //memo
 			text = item->memo;
 			break;
-		case 3: //info
-			text = item->info;
-			break;
-		case 4: //payee
+		case LST_DSPOPE_PAYEE: //payee
 			text = item->payee;
 			break;
-		case 5: //category
+		case LST_DSPOPE_CATEGORY: //category
 			text = item->category;
 			break;
 	}
@@ -249,18 +246,65 @@ GenTxn *gentxn;
 
 static gint list_txn_import_compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata)
 {
+gint sortcol = GPOINTER_TO_INT(userdata);
 gint retval = 0;
 GenTxn *gentxn1, *gentxn2;
 
     gtk_tree_model_get(model, a, LST_GENTXN_POINTER, &gentxn1, -1);
     gtk_tree_model_get(model, b, LST_GENTXN_POINTER, &gentxn2, -1);
 
-	retval = gentxn1->julian - gentxn2->julian;
+	switch(sortcol)
+	{
+		case LST_DSPOPE_MEMO:
+			retval = hb_string_utf8_compare(gentxn1->memo, gentxn2->memo);
+			break;
+		case LST_DSPOPE_AMOUNT:
+			retval = (gentxn1->amount - gentxn2->amount) > 0 ? 1 : -1;
+			break;
+		case LST_DSPOPE_PAYEE:
+			retval = hb_string_utf8_compare(gentxn1->payee, gentxn2->payee);
+			break;
+		case LST_DSPOPE_CATEGORY:
+			retval = hb_string_utf8_compare(gentxn1->category, gentxn2->category);
+			break;
+		case LST_DSPOPE_DATE:
+		default:
+			retval = gentxn1->julian - gentxn2->julian;
+			break;
+	}
 
     return retval;
 }
 
 
+static GtkTreeViewColumn *
+list_txn_import_column_text_create(gchar *title, gint sortcolumnid, gpointer user_data)
+{
+GtkTreeViewColumn  *column;
+GtkCellRenderer    *renderer;
+
+	renderer = gtk_cell_renderer_text_new ();
+	/*g_object_set(renderer, 
+		"ellipsize", PANGO_ELLIPSIZE_END,
+	    "ellipsize-set", TRUE,
+	    NULL);*/
+	if( sortcolumnid == LST_DSPOPE_AMOUNT )
+	   g_object_set(renderer, "xalign", 1.0, NULL);
+	
+	column = gtk_tree_view_column_new_with_attributes(title, renderer, NULL);
+	gtk_tree_view_column_set_alignment (column, 0.5);
+	gtk_tree_view_column_set_sort_column_id (column, sortcolumnid);
+
+	if(sortcolumnid == LST_DSPOPE_AMOUNT )
+		gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_function_amount, GINT_TO_POINTER(sortcolumnid), NULL);
+	else
+		gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_function_text, GINT_TO_POINTER(sortcolumnid), NULL);
+
+	return column;
+}
+
+
+
 static GtkWidget *list_txn_import_create(void)
 {
 GtkListStore *store;
@@ -282,7 +326,7 @@ GtkTreeViewColumn  *column;
 
 	// debug/import checkbox
 	column = gtk_tree_view_column_new();
-	#if MYDEBUG
+	#if MYDEBUG  == 1
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_function_debug, NULL, NULL);
@@ -310,20 +354,18 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_function_error, NULL, NULL);
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_function_text, GINT_TO_POINTER(1), NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_function_text, GINT_TO_POINTER(LST_DSPOPE_DATE), NULL);
 	gtk_tree_view_column_set_title (column, _("Date"));
+	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_DATE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
-	// memo	
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_tree_view_insert_column_with_data_func(GTK_TREE_VIEW(treeview), -1, 
-		_("Memo"), renderer, list_txn_cell_data_function_text, GINT_TO_POINTER(2), NULL);
+	// memo
+	column = list_txn_import_column_text_create(_("Memo"), LST_DSPOPE_MEMO, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
 	// amount
-	renderer = gtk_cell_renderer_text_new ();
-	g_object_set(renderer, "xalign", 1.0, NULL);
-	gtk_tree_view_insert_column_with_data_func(GTK_TREE_VIEW(treeview), -1, 
-		_("Amount"), renderer, list_txn_cell_data_function_amount, NULL, NULL);
+	column = list_txn_import_column_text_create(_("Amount"), LST_DSPOPE_AMOUNT, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
 	// info
 	column = gtk_tree_view_column_new();
@@ -341,20 +383,24 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
 	// payee
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_tree_view_insert_column_with_data_func(GTK_TREE_VIEW(treeview), -1, 
-		_("Payee"), renderer, list_txn_cell_data_function_text, GINT_TO_POINTER(4), NULL);
+	column = list_txn_import_column_text_create(_("Payee"), LST_DSPOPE_PAYEE, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
 	// category
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_tree_view_insert_column_with_data_func(GTK_TREE_VIEW(treeview), -1, 
-		_("Category"), renderer, list_txn_cell_data_function_text, GINT_TO_POINTER(5), NULL);
+	column = list_txn_import_column_text_create(_("Category"), LST_DSPOPE_CATEGORY, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
+	// empty 
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
-	gtk_tree_sortable_set_default_sort_func(GTK_TREE_SORTABLE(store), list_txn_import_compare_func, NULL, NULL);
-	
+	//gtk_tree_sortable_set_default_sort_func(GTK_TREE_SORTABLE(store), list_txn_import_compare_func, NULL, NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_DATE    , list_txn_import_compare_func, GINT_TO_POINTER(LST_DSPOPE_DATE), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_MEMO    , list_txn_import_compare_func, GINT_TO_POINTER(LST_DSPOPE_MEMO), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_AMOUNT  , list_txn_import_compare_func, GINT_TO_POINTER(LST_DSPOPE_AMOUNT), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_PAYEE   , list_txn_import_compare_func, GINT_TO_POINTER(LST_DSPOPE_PAYEE), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_CATEGORY, list_txn_import_compare_func, GINT_TO_POINTER(LST_DSPOPE_CATEGORY), NULL);
+
 	return(treeview);
 }
 
@@ -692,7 +738,7 @@ gint res;
 	gtk_window_set_position(GTK_WINDOW(data->assistant), GTK_WIN_POS_CENTER_ON_PARENT);
 
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(dialog), PREFS->path_import);
-	DB( g_print(" -> set current folder '%s'\n", PREFS->path_import) );
+	DB( g_print(" set current folder '%s'\n", PREFS->path_import) );
 
 	gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(dialog), TRUE);
 
@@ -747,7 +793,7 @@ gint res;
 		{
 		GenFile *genfile;
 
-			DB( g_print(" selected '%p'\n", list->data) );
+			DB( g_print("  selected '%p'\n", list->data) );
 
 			genfile = da_gen_file_append_from_filename(ictx, list->data);
 			if(genfile)
@@ -759,7 +805,7 @@ gint res;
 
 		/* remind folder to preference */
 		gchar *folder = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER(chooser));
-		DB( g_print(" -> store folder '%s'\n", folder) );
+		DB( g_print(" store folder '%s'\n", folder) );
 		g_free(PREFS->path_import);
 		PREFS->path_import = folder;
 	}
@@ -831,24 +877,24 @@ GString *node;
 
 static gboolean ui_import_page_import_eval(GtkWidget *widget, gpointer user_data)
 {
-struct import_data *data;
-ImportContext *ictx;
-gint count;
+//struct import_data *data;
+//ImportContext *ictx;
+//gint count;
 
 	DB( g_print("\n[ui-import] page_import_eval\n") );
 
 
-	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-	ictx = &data->ictx;
+	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+	//ictx = &data->ictx;
 
-	count = g_list_length (ictx->gen_lst_acc);
+	//count = g_list_length (ictx->gen_lst_acc);
 
-	DB( g_print(" - count=%d (max=%d)\n", count, TXN_MAX_ACCOUNT) );
+	//DB( g_print(" count=%d (max=%d)\n", count, TXN_MAX_ACCOUNT) );
 
-	if( count <= TXN_MAX_ACCOUNT )
+	//if( count <= TXN_MAX_ACCOUNT )
 		return TRUE;
 
-	return FALSE;
+	//return FALSE;
 }
 
 
@@ -886,10 +932,29 @@ gint count = 0;
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
+static ImpTxnData *ui_import_page_transaction_data_get(GArray *txndata, guint32 idx)
+{
+//gint i;
+	
+	/*g_print(" array @%p, len is %d\n", txndata, txndata->len);
+	for(i=0;i<txndata->len;i++)
+		g_print(" %d %p\n", i, &g_array_index(txndata, ImpTxnData, i) );
+
+	g_print(" get idx=%d - %p\n", idx, &g_array_index (txndata, ImpTxnData, idx) );
+	*/
+
+	if( idx <= txndata->len )
+		return &g_array_index (txndata, ImpTxnData, idx);
+	return NULL;
+}
+
+
+
+
 static void ui_import_page_transaction_cb_fill_same(GtkTreeSelection *treeselection, gpointer user_data)
 {
 struct import_data *data;
-struct import_txndata *txndata;
+ImpTxnData *txndata;
 //ImportContext *ictx;
 GtkTreeSelection *selection;
 GtkTreeModel		 *model, *dupmodel;
@@ -910,7 +975,8 @@ guint count = 0;
 	gint acckey =  pageidx - (PAGE_IMPORT);
 	//GenAcc *genacc = da_gen_acc_get_by_key(ictx->gen_lst_acc, acckey);
 
-	txndata = &data->txndata[acckey];
+	//txndata = &data->txndata[acckey];
+	txndata = ui_import_page_transaction_data_get(data->txndata, acckey);
 
 	dupmodel = gtk_tree_view_get_model(GTK_TREE_VIEW(txndata->LV_duptxn));
 	gtk_list_store_clear (GTK_LIST_STORE(dupmodel));
@@ -953,7 +1019,7 @@ guint count = 0;
 
 static void ui_import_page_transaction_options_get(struct import_data *data)
 {
-struct import_txndata *txndata;
+ImpTxnData *txndata;
 ImportContext *ictx;
 
 
@@ -965,7 +1031,8 @@ ImportContext *ictx;
 	gint accidx =  pageidx - (PAGE_IMPORT);
 	//GenAcc *genacc = g_list_nth_data(ictx->gen_lst_acc, accidx);
 
-	txndata = &data->txndata[accidx];
+	//txndata = &data->txndata[accidx];
+	txndata = ui_import_page_transaction_data_get(data->txndata, accidx);
 
 	ictx->opt_dateorder = gtk_combo_box_get_active (GTK_COMBO_BOX(txndata->CY_txn_dateorder));
 	ictx->opt_daygap    = gtk_spin_button_get_value(GTK_SPIN_BUTTON(txndata->NB_txn_daygap));
@@ -977,13 +1044,13 @@ ImportContext *ictx;
 	ictx->opt_qifmemo   = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(txndata->CM_txn_qifmemo));
 	ictx->opt_qifswap   = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(txndata->CM_txn_qifswap));
 
-	DB( g_print(" - datefmt  = '%s' (%d)\n", CYA_IMPORT_DATEORDER[ictx->opt_dateorder], ictx->opt_dateorder) );
+	DB( g_print(" datefmt  = '%s' (%d)\n", CYA_IMPORT_DATEORDER[ictx->opt_dateorder], ictx->opt_dateorder) );
 }
 
 
 static void ui_import_page_transaction_update(struct import_data *data)
 {
-struct import_txndata *txndata;
+ImpTxnData *txndata;
 ImportContext *ictx;
 gboolean sensitive, visible;
 gboolean iscomplete;
@@ -998,7 +1065,8 @@ GtkTreeModel *model;
 	//GenAcc *genacc = g_list_nth_data(ictx->gen_lst_acc, acckey);
 	GenAcc *genacc = da_gen_acc_get_by_key(ictx->gen_lst_acc, acckey);
 
-	txndata = &data->txndata[acckey];
+	//txndata = &data->txndata[acckey];
+	txndata = ui_import_page_transaction_data_get(data->txndata, acckey);
 
 	DB( g_print(" page idx:%d, genacckey:%d genacc:%p, txndata:%p\n", pageidx, acckey, genacc, txndata) );
 
@@ -1010,7 +1078,7 @@ GtkTreeModel *model;
 		hb_widget_visible (txndata->IM_unamed, visible);
 
 		sensitive = (genacc->kacc == DST_ACC_SKIP) ? FALSE : TRUE;
-		DB( g_print("- sensitive=%d\n", sensitive) );
+		DB( g_print(" sensitive=%d\n", sensitive) );
 
 		gtk_widget_set_sensitive(txndata->LV_gentxn, sensitive);
 		gtk_widget_set_sensitive(txndata->EX_duptxn, sensitive);
@@ -1027,15 +1095,15 @@ GtkTreeModel *model;
 		iscomplete = (genacc->n_txnbaddate > 0) ? FALSE : TRUE;
 		iscomplete = (genacc->kacc == DST_ACC_SKIP) ? TRUE : iscomplete;
 
-		DB( g_print("- nbbaddates=%d, dstacc=%d\n", genacc->n_txnbaddate, genacc->kacc) );
-		DB( g_print("- iscomplete=%d\n", iscomplete) );
+		DB( g_print(" nbbaddates=%d, dstacc=%d\n", genacc->n_txnbaddate, genacc->kacc) );
+		DB( g_print(" iscomplete=%d\n", iscomplete) );
 		
 		//show/hide invalid date group
 		visible = FALSE;
 		if(genacc->n_txnbaddate > 0)
 		{
 			visible = TRUE;
-			DB( g_print(" - invalid date detected\n" ) );
+			DB( g_print(" invalid date detected\n" ) );
 			msg_icon = ICONNAME_ERROR;
 			msg_label = 
 				_("Some date cannot be converted. Please try to change the date order to continue.");
@@ -1052,8 +1120,9 @@ GtkTreeModel *model;
 
 		model = gtk_tree_view_get_model(GTK_TREE_VIEW(txndata->LV_gentxn));
 
-		gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(model), GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
-		gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(model), GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
+		gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(model), LST_DSPOPE_DATE, GTK_SORT_ASCENDING);
+		//gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(model), GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
+		//gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(model), GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
 		
 		GtkWidget *page = gtk_assistant_get_nth_page (GTK_ASSISTANT(data->assistant), pageidx);
 		gtk_assistant_set_page_complete(GTK_ASSISTANT(data->assistant), page, iscomplete);
@@ -1065,7 +1134,7 @@ GtkTreeModel *model;
 static void ui_import_page_transaction_cb_account_changed(GtkWidget *widget, gpointer user_data)
 {
 struct import_data *data;
-struct import_txndata *txndata;
+ImpTxnData *txndata;
 ImportContext *ictx;
 gint dstacc;
 
@@ -1080,7 +1149,8 @@ gint dstacc;
 	//GenAcc *genacc = g_list_nth_data(ictx->gen_lst_acc, accidx);
 	GenAcc *genacc = da_gen_acc_get_by_key(ictx->gen_lst_acc, acckey);
 	
-	txndata = &data->txndata[acckey];
+	//txndata = &data->txndata[acckey];
+	txndata = ui_import_page_transaction_data_get(data->txndata, acckey);
 
 	dstacc = ui_genacc_comboboxtext_get_active (txndata->CY_acc);
 	genacc->kacc = dstacc;
@@ -1100,7 +1170,7 @@ gint dstacc;
 static void ui_import_page_transaction_cb_option_changed(GtkWidget *widget, gpointer user_data)
 {
 struct import_data *data;
-struct import_txndata *txndata;
+ImpTxnData *txndata;
 ImportContext *ictx;
 
 
@@ -1115,7 +1185,8 @@ ImportContext *ictx;
 	//GenAcc *genacc = g_list_nth_data(ictx->gen_lst_acc, accidx);
 	GenAcc *genacc = da_gen_acc_get_by_key(ictx->gen_lst_acc, acckey);
 
-	txndata = &data->txndata[acckey];
+	//txndata = &data->txndata[acckey];
+	txndata = ui_import_page_transaction_data_get(data->txndata, acckey);
 
 	ui_import_page_transaction_options_get(data);
 	hb_import_option_apply(ictx, genacc);
@@ -1128,7 +1199,7 @@ ImportContext *ictx;
 
 static void ui_import_page_transaction_fill(struct import_data *data)
 {
-struct import_txndata *txndata;
+ImpTxnData *txndata;
 ImportContext *ictx = &data->ictx;
 GtkWidget *view;
 GtkTreeModel *model;
@@ -1147,8 +1218,10 @@ gboolean visible;
 	//GenAcc *genacc = g_list_nth_data(ictx->gen_lst_acc, acckey);
 	GenAcc *genacc = da_gen_acc_get_by_key(ictx->gen_lst_acc, acckey);
 	//nbacc = g_list_length(ictx->gen_lst_acc);
-	txndata = &data->txndata[acckey];
-
+	
+	//txndata = &data->txndata[acckey];
+	txndata = ui_import_page_transaction_data_get(data->txndata, acckey);
+	
 	DB( g_print(" genacckey:%d genacc:%p, txndata:%p\n", acckey, genacc, txndata) );
 	
 	if(genacc)
@@ -1190,7 +1263,7 @@ gboolean visible;
 					LST_GENTXN_POINTER, item,
 					-1);
 
-				DB( g_print(" - fill: %d, %d, %s %.2f\n", item->account, item->julian, item->memo, item->amount) );
+				DB( g_print(" fill: %s, %d, %s %.2f\n", item->account, item->julian, item->memo, item->amount) );
 				count++;
 			}
 			tmplist = g_list_next(tmplist);
@@ -1506,13 +1579,23 @@ GenTxn *gentxn;
 static GtkWidget *
 ui_import_page_transaction_create (GtkWidget *assistant, gint idx, struct import_data *data)
 {
-struct import_txndata *txndata;
+ImpTxnData *txndata;
 GtkWidget *table, *box, *group, *stack;
 GtkWidget *label, *scrollwin, *expander, *widget;
+ImpTxnData tmp;
 gint row;
-	
-	txndata = &data->txndata[idx];
 
+	//txndata = &data->txndata[idx];
+	memset(&tmp, 0, sizeof(ImpTxnData));
+	g_array_insert_vals(data->txndata, idx, &tmp, 1);
+
+	txndata = ui_import_page_transaction_data_get(data->txndata, idx);
+
+	DB( g_print(" txndat=%p\n", txndata) );
+
+	if(!txndata)
+		return NULL;
+	
 	table = gtk_grid_new ();
 	gtk_grid_set_row_spacing (GTK_GRID (table), SPACING_SMALL);
 	gtk_grid_set_column_spacing (GTK_GRID (table), SPACING_MEDIUM);
@@ -1805,7 +1888,7 @@ gint next_page;
 	
 	DB( g_print(" -> current: %d %s\n", current_page, gtk_assistant_get_page_title(GTK_ASSISTANT(data->assistant), page) ) );
 
-#ifdef MYDEBUG
+#if MYDEBUG == 1
 
 	struct import_data *data = func_data;
 	gint i
@@ -1840,7 +1923,7 @@ ui_import_assistant_prepare (GtkWidget *widget, GtkWidget *page, gpointer user_d
 {
 struct import_data *data;
 ImportContext *ictx;
-gint current_page, n_pages, i;
+gint current_page, n_pages;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -1854,12 +1937,12 @@ gint current_page, n_pages, i;
 	switch( current_page )
 	{
 		case PAGE_WELCOME:
-			DB( g_print(" -> 1 intro\n") );
+			DB( g_print("\n #1 intro\n") );
 			gtk_assistant_set_page_complete (GTK_ASSISTANT(data->assistant), page, TRUE);
 			break;
 
 		case PAGE_FILES:
-			DB( g_print(" -> 2 file choose\n") );
+			DB( g_print("\n #2 file choose\n") );
 			gtk_assistant_set_page_complete (GTK_ASSISTANT(data->assistant), page, FALSE);
 
 			//open the file add if no file
@@ -1875,30 +1958,29 @@ gint current_page, n_pages, i;
 			break;
 
 		case PAGE_IMPORT:
-			DB( g_print(" -> 3 real import\n") );
+			DB( g_print("\n #3 real import\n") );
 			gtk_assistant_set_page_complete (GTK_ASSISTANT(data->assistant), page, FALSE);
 
 			//todo: more test needed here
 			//clean any previous txn page
-			for(i=(n_pages-1);i>=PAGE_IMPORT+1;i--)
+			/*for(i=(n_pages-1);i>=PAGE_IMPORT+1;i--)
 			{
 			GtkWidget *page = gtk_assistant_get_nth_page (GTK_ASSISTANT(data->assistant), i);
-			GtkAssistantPageType pagetype;
+			gboolean isacc;
 				
 				if( page != NULL )
 				{
-					pagetype = gtk_assistant_get_page_type(GTK_ASSISTANT(data->assistant), page);
+					isacc = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(page), "pgacc"));
 
-					DB( g_print(" %d page_type:%d\n", i, pagetype) );
+					DB( g_print(" %d is acc: %d\n", i, isacc) );
 
-					if( pagetype == GTK_ASSISTANT_PAGE_CONTENT || pagetype == GTK_ASSISTANT_PAGE_CUSTOM )
+					if( isacc )
 					{
 						gtk_assistant_remove_page(GTK_ASSISTANT(data->assistant), i);
 						gtk_widget_destroy (page);
-
 					}
 				}
-			}
+			}*/
 			
 			hb_import_load_all(&data->ictx);
 
@@ -1906,13 +1988,26 @@ gint current_page, n_pages, i;
 			gint key, nbacc;
 			nbacc = g_list_length (ictx->gen_lst_acc);
 
-			DB( g_print(" nb account %d (max=%d)\n", nbacc, TXN_MAX_ACCOUNT) );
+			if(data->txndata)
+			{
+				g_array_free(data->txndata, TRUE);
+				data->txndata = NULL;
+			}
+			data->txndata = g_array_sized_new(FALSE, TRUE, sizeof(ImpTxnData), nbacc);
 
+			//#1820618 patch for glib < 2.58 https://gitlab.gnome.org/GNOME/glib/issues/1374
+			if( glib_minor_version < 58 )
+			{
+				g_array_set_size(data->txndata, nbacc);
+			}
+			
+			DB( g_print(" accnb=%d @%p\n", nbacc, data->txndata) );
+			
 			//debug
 			//_import_context_debug_acc_list(&data->ictx);
 			
-			if(nbacc < TXN_MAX_ACCOUNT)
-			{
+			//if(nbacc < TXN_MAX_ACCOUNT)
+			//{
 				for(key=1;key<nbacc+1;key++)
 				{
 				GtkWidget *page;
@@ -1924,6 +2019,7 @@ gint current_page, n_pages, i;
 					DB( g_print(" create page txn for '%s' '%s' at page %d\n", genacc->name, genacc->number, PAGE_IMPORT + key) );
 
 					page = ui_import_page_transaction_create (data->assistant, key, data);
+					//g_object_set_data(G_OBJECT(page), "pgacc", (gpointer)TRUE);
 					gtk_widget_show_all (page);
 					gtk_assistant_insert_page (GTK_ASSISTANT (data->assistant), page, PAGE_IMPORT + key);
 					//gtk_assistant_set_page_title (GTK_ASSISTANT (data->assistant), page, _("Transaction"));
@@ -1933,7 +2029,7 @@ gint current_page, n_pages, i;
 					gtk_assistant_set_page_title (GTK_ASSISTANT (data->assistant), page, title);
 					g_free(title);
 				}
-			}
+			//}
 			
 			// obsolete ??
 			if( ui_import_page_import_eval (widget, NULL) )
@@ -1961,10 +2057,10 @@ gint current_page, n_pages, i;
 		default:
 			if(current_page != (n_pages - 1))
 			{
-				DB( g_print(" -> 6 transaction\n") );
+				DB( g_print("\n #4 transaction\n") );
 
 				if( current_page == PAGE_IMPORT + 1)
-					//hact to get rid of back button
+					//hack to get rid of back button
 					gtk_assistant_set_page_type (GTK_ASSISTANT(data->assistant), page, GTK_ASSISTANT_PAGE_INTRO);
 				
 				ui_import_page_transaction_fill(data);
@@ -1972,7 +2068,7 @@ gint current_page, n_pages, i;
 			}
 			else
 			{	
-				DB( g_print(" -> 7 confirmation\n") );
+				DB( g_print("\n #5 confirmation\n") );
 
 			//todo: auto assignment should be optional
 				//data->imp_cnt_asg = transaction_auto_assign(ictx->trans_list, 0);
@@ -2012,6 +2108,11 @@ struct import_data *data = user_data;
 
 	da_import_context_destroy(&data->ictx);
 
+	if(data->txndata)
+	{
+		g_array_free(data->txndata, TRUE);
+	}
+
 
 	// todo: optimize this
 	//if(data->imp_cnt_trn > 0)
