@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -35,11 +35,8 @@ extern struct HomeBank *GLOBALS;
 extern struct Preferences *PREFS;
 
 
-gchar *CYA_CAT_TYPE[] = { 
-	N_("Expense"), 
-	N_("Income"), 
-	NULL
-};
+extern gchar *CYA_CAT_TYPE[];
+
 
 static void ui_cat_manage_populate_listview(struct ui_cat_manage_dialog_data *data);
 
@@ -206,7 +203,7 @@ gchar type;
 	{
 		pitem = da_cat_get(item->parent);
 
-		type = (item->flags & GF_INCOME) ? '+' : '-';
+		type = category_get_type_char(item);
 		fullname = item->fullname;
 		sortname = NULL;
 		name = NULL;
@@ -574,10 +571,10 @@ gchar *string;
 	else
 		name = entry->name;
 
-	gchar type = (entry->flags & GF_INCOME) ? '+' : '-';
+	gchar type = category_get_type_char(entry);
 
 	#if MYDEBUG
-	string = g_markup_printf_escaped ("%d > [%d] %s [%c] %d", entry->key, entry->parent, name, type, entry->flags );
+	string = g_markup_printf_escaped ("%d > [%d] %s [%c] %d %c", entry->key, entry->parent, name, type, entry->flags, (entry->flags & GF_MIXED) ?'m':' ' );
 	#else
 	if(entry->key == 0)
 		string = g_strdup(name);
@@ -1030,6 +1027,7 @@ GtkTreeViewColumn	*column;
 		gtk_tree_view_column_pack_start(column, renderer, TRUE);
 		gtk_tree_view_column_set_cell_data_func(column, renderer, ui_cat_listview_count_cell_data_function, GINT_TO_POINTER(LST_DEFCAT_DATAS), NULL);
 		gtk_tree_view_column_set_alignment (column, 0.5);
+		//gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
 		gtk_tree_view_column_set_sort_column_id (column, LST_DEFCAT_SORT_USED);
 		gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	}
@@ -1219,7 +1217,7 @@ gint type;
 			/* if cat use new id */
 			if(subcat == FALSE)
 			{
-				type = radio_get_active(GTK_CONTAINER(data->RA_type));
+				type = hbtk_radio_get_active(GTK_CONTAINER(data->RA_type));
 				if(type == 1)
 					item->flags |= GF_INCOME;
 
@@ -1760,7 +1758,7 @@ static void ui_cat_manage_populate_listview(struct ui_cat_manage_dialog_data *da
 {
 gint type;
 
-	type = radio_get_active(GTK_CONTAINER(data->RA_type)) == 1 ? CAT_TYPE_INCOME : CAT_TYPE_EXPENSE;
+	type = hbtk_radio_get_active(GTK_CONTAINER(data->RA_type)) == 1 ? CAT_TYPE_INCOME : CAT_TYPE_EXPENSE;
 	ui_cat_listview_populate(data->LV_cat, type);
 	gtk_tree_view_expand_all (GTK_TREE_VIEW(data->LV_cat));
 }
@@ -1838,14 +1836,12 @@ gint w, h, row;
 	gtk_box_pack_start (GTK_BOX (mainvbox), table, TRUE, TRUE, 0);
 
 	row = 0;
-	bbox = make_radio(CYA_CAT_TYPE, TRUE, GTK_ORIENTATION_HORIZONTAL);
+	bbox = hbtk_radio_new(CYA_CAT_TYPE, TRUE);
 	data.RA_type = bbox;
 	gtk_widget_set_halign (bbox, GTK_ALIGN_CENTER);
 	gtk_grid_attach (GTK_GRID (table), bbox, 0, row, 2, 1);
 
-	widget = radio_get_nth_widget(GTK_CONTAINER(bbox), 1);
-	if(widget)
-		g_signal_connect (widget, "toggled", G_CALLBACK (ui_cat_manage_type_changed_cb), &data);
+	hbtk_radio_connect (GTK_CONTAINER(bbox), "toggled", G_CALLBACK (ui_cat_manage_type_changed_cb), &data);
 
 	menu = gtk_menu_new ();
 	gtk_widget_set_halign (menu, GTK_ALIGN_END);
