@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -42,66 +42,12 @@
 extern struct HomeBank *GLOBALS;
 
 
+extern gchar *CYA_FLT_TYPE[];
+extern gchar *CYA_FLT_STATUS[];
+extern gchar *CYA_FLT_RANGE[];
+extern gchar *CYA_SELECT[];
 extern char *paymode_label_names[];
-
-
-gchar *CYA_FLT_TYPE[] = {
-	N_("Expense"),
-	N_("Income"),
-	"",
-	N_("Any Type"),
-	NULL
-};
-
-gchar *CYA_FLT_STATUS[] = {
-	N_("Uncategorized"),
-	N_("Unreconciled"),
-	N_("Uncleared"),
-	N_("Reconciled"),
-	N_("Cleared"),
-	"",
-	N_("Any Status"),
-	NULL
-};
-
-gchar *CYA_FLT_RANGE[] = {
-	N_("This month"),
-	N_("Last month"),
-	N_("This quarter"),
-	N_("Last quarter"),
-	N_("This year"),
-	N_("Last year"),
-	"",
-	N_("Last 30 days"),
-	N_("Last 60 days"),
-	N_("Last 90 days"),
-	N_("Last 12 months"),
-	"",
-	N_("Other..."),
-	"",
-	N_("All date"),
-	NULL
-};
-
-
-gchar *CYA_SELECT[] =
-{
-	"----",
-	N_("All month"),
-	N_("January"),
-	N_("February"),
-	N_("March"),
-	N_("April"),
-	N_("May"),
-	N_("June"),
-	N_("July"),
-	N_("August"),
-	N_("September"),
-	N_("October"),
-	N_("November"),
-	N_("December"),
-	NULL
-};
+extern gchar *nainex_label_names[];
 
 
 /* = = = = = = = = = = = = = = = = = = = = */
@@ -972,7 +918,7 @@ struct ui_flt_manage_data *data;
 
 	DB( g_print("(ui_flt_manage) clear\n") );
 
-	filter_default_all_set(data->filter);
+	filter_reset(data->filter);
 
 	ui_flt_manage_set(data);
 
@@ -1316,9 +1262,11 @@ gint row;
 
 		row++;
 		label = make_label_widget(_("Force:"));
+		data->LB_force = label;
 		gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
 
 		vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+		data->GR_force = vbox;
 		gtk_grid_attach (GTK_GRID (table), vbox, 2, row, 1, 1);
 
 		widget = gtk_check_button_new_with_mnemonic (_("display 'Added'"));
@@ -1386,20 +1334,18 @@ gint i, row;
 /*
 **
 */
-gint ui_flt_manage_dialog_new(GtkWidget *widget, Filter *filter, gboolean show_account)
+gint ui_flt_manage_dialog_new(GtkWindow *parentwindow, Filter *filter, gboolean show_account, gboolean txnmode)
 {
 struct ui_flt_manage_data data;
-GtkWidget *parentwindow, *window, *content, *mainbox, *box, *sidebar, *stack, *page;
-gint w, h;
+GtkWidget *window, *content, *mainbox, *box, *sidebar, *stack, *page;
+//gint w, h;
 
 	//data = g_malloc0(sizeof(struct ui_flt_manage_data));
 	//if(!data) return NULL;
-	memset(&data, 0, sizeof(data));
+	memset(&data, 0, sizeof(struct ui_flt_manage_data));
 
 	data.filter = filter;
 
-	parentwindow = gtk_widget_get_ancestor(GTK_WIDGET(widget), GTK_TYPE_WINDOW);
-
 	window = gtk_dialog_new_with_buttons (_("Edit filter"),
 					    GTK_WINDOW (parentwindow),
 					    0,
@@ -1414,8 +1360,8 @@ gint w, h;
 	gtk_window_set_icon_name(GTK_WINDOW (window), ICONNAME_HB_FILTER);
 
 	//set a nice dialog size
-	gtk_window_get_size(GTK_WINDOW(parentwindow), &w, &h);
-	gtk_window_set_default_size (GTK_WINDOW(window), -1, 0.8*h);
+	//gtk_window_get_size(GTK_WINDOW(parentwindow), &w, &h);
+	//gtk_window_set_default_size (GTK_WINDOW(window), -1, 0.8*h);
 
 
 	//store our window private data
@@ -1491,7 +1437,6 @@ gint w, h;
 	ui_flt_manage_set(&data);
 
 	ui_flt_manage_option_update(window, NULL);
-
 	
 	/* signal connect */
     g_signal_connect (data.CY_option[FILTER_STATUS]  , "changed", G_CALLBACK (ui_flt_manage_option_update), NULL);
@@ -1515,6 +1460,12 @@ gint w, h;
 
 	gtk_widget_show_all (window);
 
+	if(!txnmode)
+	{
+		hb_widget_visible (data.LB_force, FALSE);
+		hb_widget_visible (data.GR_force, FALSE);
+	}
+
 
 	if( *data.filter->last_tab != '\0' )
 		gtk_stack_set_visible_child_name (GTK_STACK(data.stack), data.filter->last_tab);
