@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -932,7 +932,9 @@ guint32 key;
 		row++;
 		label = make_label_widget(_("Pa_yment:"));
 		gtk_grid_attach (GTK_GRID (group_grid), label, 0, row, 1, 1);
-		widget = make_paymode(label);
+		//5.2.4 we drop internal xfer here as it will disapear 
+		//widget = make_paymode_nointxfer(label);
+		widget = make_paymode_nointxfer(label);
 		NU_mode = widget;
 		gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 1, 1);
 
