@@ -1,5 +1,5 @@
 /*	HomeBank -- Free, easy, personal accounting for everyone.
- *	Copyright (C) 1995-2018 Maxime DOYEN
+ *	Copyright (C) 1995-2019 Maxime DOYEN
  *
  *	This file is part of HomeBank.
  *
@@ -25,7 +25,7 @@
 #include "ui-payee.h"
 #include "ui-category.h"
 #include "gtk-dateentry.h"
-#include "list_operation.h"
+#include "list-operation.h"
 
 
 /****************************************************************************/
@@ -161,7 +161,7 @@ GList *selection, *list;
 }
 
 
-gint ui_multipleedit_dialog_apply( GtkWidget *widget, gboolean **do_sort )
+gint ui_multipleedit_dialog_apply( GtkWidget *widget, gboolean *do_sort )
 {
 struct ui_multipleedit_dialog_data *data;
 GtkTreeModel *model;
