@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -190,6 +190,30 @@ gchar buf[16];
 }
 
 
+void ui_gtk_entry_tag_name_append(GtkEntry *entry, gchar *tagname)
+{
+GtkEntryBuffer *buffer;
+const gchar *text;
+guint len;
+
+	text = gtk_entry_get_text(entry);
+	if( g_strstr_len(text, -1, tagname) == NULL )
+	{
+		DB( g_print(" gtkentry append tagname '%'\n", tagname) );
+		buffer = gtk_entry_get_buffer(GTK_ENTRY(entry));
+		if(buffer)
+		{
+			len = gtk_entry_buffer_get_length(buffer);
+			DB( g_print("- add ' %s' %p %d\n", tagname, buffer, len) );
+			if(len > 0)
+				gtk_entry_buffer_insert_text(buffer, len, " ", 1);
+			gtk_entry_buffer_insert_text(buffer, len+1, tagname, -1);
+		}
+	}
+
+}
+
+
 void ui_gtk_entry_set_text(GtkWidget *widget, gchar *text)
 {
 	DB( g_print(" set text to '%s'\n", text) );
@@ -317,7 +341,7 @@ GtkWidget *button, *image;
 	//todo 3.10 use gtk_button_new_from_icon_name 
 
 	button = gtk_button_new();
-	image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
+	image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_BUTTON);
 	g_object_set (button, "image", image, NULL);
 	if(tooltip_text != NULL)
 		gtk_widget_set_tooltip_text(button, tooltip_text);
@@ -656,55 +680,124 @@ guint i;
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
-guint32 hb_combo_box_get_active_id(GtkComboBox *combobox)
+#define HB_KV_BUFFER_MAX_LEN	8
+#define HB_KV_ITEMS_MAX_LEN		32
+
+gchar *hbtk_get_label(HbKvData *kvdata, guint32 key)
 {
-const gchar* active_id = gtk_combo_box_get_active_id(combobox);
-	return atoi(active_id);
+gchar *retval = NULL;
+guint32 i;
+
+	for(i=0;i<HB_KV_ITEMS_MAX_LEN;i++)
+	{
+	HbKvData *tmp = &kvdata[i];
+		if( tmp->name == NULL )
+			break;
+		if( tmp->key == key )
+		{
+			//#1820372
+			retval = (gchar *)_(tmp->name);
+			break;
+		}
+	}
+	return retval;
 }
 
 
-void hb_combo_box_set_active_id(GtkComboBox *combobox, guint32 active_id)
+static gboolean hbtk_combo_box_is_separator (GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
 {
-gchar idbuffer[12];
+//GtkTreePath *path;
+gboolean retval;
+gchar *txt;
 
-	g_snprintf(idbuffer, 11, "%d", active_id);
-	gtk_combo_box_set_active_id(combobox, idbuffer);
+	gtk_tree_model_get (model, iter, 0, &txt, -1);
+	retval = *txt == 0 ? TRUE : FALSE;
+	//leak
+	g_free(txt);
+
+	return retval;
+}
+
+
+guint32 hbtk_combo_box_get_active_id (GtkComboBoxText *combobox)
+{
+const gchar* buf;
+guint32 retval;
+	
+	buf = gtk_combo_box_get_active_id(GTK_COMBO_BOX(combobox));
+	retval = buf != NULL ? atoi(buf) : 0;
+
+	return retval;
+}
+
+
+void hbtk_combo_box_set_active_id (GtkComboBoxText *combobox, guint32 key)
+{
+gchar buf[HB_KV_BUFFER_MAX_LEN];
+
+	g_snprintf(buf, HB_KV_BUFFER_MAX_LEN-1, "%d", key);
+	gtk_combo_box_set_active_id(GTK_COMBO_BOX(combobox), buf);
+}
+
+
+void hbtk_combo_box_text_append (GtkComboBoxText *combobox, guint32 key, gchar *text)
+{
+gchar buf[HB_KV_BUFFER_MAX_LEN];
+
+	g_snprintf(buf, HB_KV_BUFFER_MAX_LEN-1, "%d", key);
+	gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(combobox), buf, text);
+}
+
+
+GtkWidget *hbtk_combo_box_new (GtkWidget *label)
+{
+GtkWidget *combobox;
+
+	combobox = gtk_combo_box_text_new();
+	
+	if(label)
+		gtk_label_set_mnemonic_widget (GTK_LABEL(label), combobox);
+
+	return combobox;
+}
+
+
+GtkWidget *hbtk_combo_box_new_with_data (GtkWidget *label, HbKvData *kvdata)
+{
+GtkWidget *combobox = hbtk_combo_box_new(label);
+HbKvData *tmp;
+gboolean hassep;
+guint32 i;
+
+	hassep = FALSE;
+	for(i=0;i<HB_KV_ITEMS_MAX_LEN;i++)
+	{
+		tmp = &kvdata[i];
+		if( tmp->name == NULL )
+			break;
+		if( *tmp->name != 0 )
+		{
+			hbtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(combobox), tmp->key, (gchar *)_(tmp->name));
+		}
+		else
+		{
+			hbtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(combobox), tmp->key, (gchar *)"");
+			hassep = TRUE;
+		}
+	}
+	gtk_combo_box_set_active(GTK_COMBO_BOX(combobox), 0);
+
+	if(hassep)
+		gtk_combo_box_set_row_separator_func (GTK_COMBO_BOX (combobox), hbtk_combo_box_is_separator, NULL, NULL);
+
+	return combobox;
 }
 
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
-/*
-**
-*/
-GtkWidget *make_radio(gchar **items, gboolean buttonstyle, GtkOrientation orientation)
-{
-GtkWidget *box, *button;
-guint i;
 
-	box = gtk_box_new (orientation, 0);
-
-    button = gtk_radio_button_new_with_label (NULL, _(items[0]));
-	gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (button), !buttonstyle);
-    gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 0);
-	for (i = 1; items[i] != NULL; i++)
-	{
-		button = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (button), _(items[i]));
-		gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (button), !buttonstyle);
-	    gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 0);
-	}
-
-	if(buttonstyle)
-	{
-		gtk_style_context_add_class (gtk_widget_get_style_context (box), GTK_STYLE_CLASS_LINKED);
-		gtk_style_context_add_class (gtk_widget_get_style_context (box), GTK_STYLE_CLASS_RAISED);
-	}
-	
-	return box;
-}
-
-
-gint radio_get_active (GtkContainer *container)
+gint hbtk_radio_get_active (GtkContainer *container)
 {
 GList *lchild, *list;
 GtkWidget *radio;
@@ -732,23 +825,8 @@ gint i, retval = 0;
 	return retval;
 }
 
-GtkWidget *radio_get_nth_widget (GtkContainer *container, gint nth)
-{
-GList *lchild, *list;
-GtkWidget *radio;
 
-	if(!GTK_IS_CONTAINER(container))
-		return NULL;
-
-	lchild = list = gtk_container_get_children (container);
-	radio = g_list_nth_data (list, nth);
-	g_list_free(lchild);
-	return radio;   //may return NULL
-}
-
-
-
-void radio_set_active (GtkContainer *container, gint active)
+void hbtk_radio_set_active (GtkContainer *container, gint active)
 {
 GList *lchild, *list;
 GtkWidget *radio;
@@ -766,6 +844,72 @@ GtkWidget *radio;
 }
 
 
+GtkWidget *hbtk_radio_get_nth (GtkContainer *container, gint nth)
+{
+GList *lchild, *list;
+GtkWidget *radio;
+
+	if(!GTK_IS_CONTAINER(container))
+		return NULL;
+
+	lchild = list = gtk_container_get_children (container);
+	radio = g_list_nth_data (list, nth);
+	g_list_free(lchild);
+	return radio;   //may return NULL
+}
+
+
+void hbtk_radio_connect(GtkContainer *container, const gchar *detailed_signal, GCallback c_handler, gpointer data)
+{
+GList *lchild, *list;
+GtkWidget *radio;
+gint i;
+
+	if(!GTK_IS_CONTAINER(container))
+		return;
+
+	lchild = list = gtk_container_get_children (container);
+	for(i=0;list != NULL;i++)
+	{
+		radio = list->data;
+		if(GTK_IS_TOGGLE_BUTTON(radio))
+		{
+			g_signal_connect (radio, "toggled", c_handler, data);
+		}
+		list = g_list_next(list);
+	}
+	g_list_free(lchild);
+
+}
+
+
+GtkWidget *hbtk_radio_new (gchar **items, gboolean buttonstyle)
+{
+GtkWidget *box, *button, *newbutton;
+guint i;
+
+	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+
+    button = gtk_radio_button_new_with_label (NULL, _(items[0]));
+	gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (button), !buttonstyle);
+    gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 0);
+	for (i = 1; items[i] != NULL; i++)
+	{
+		newbutton = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (button), _(items[i]));
+		gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (newbutton), !buttonstyle);
+	    gtk_box_pack_start (GTK_BOX (box), newbutton, FALSE, FALSE, 0);
+	}
+
+	if(buttonstyle)
+	{
+		gtk_style_context_add_class (gtk_widget_get_style_context (box), GTK_STYLE_CLASS_LINKED);
+		gtk_style_context_add_class (gtk_widget_get_style_context (box), GTK_STYLE_CLASS_RAISED);
+	}
+	
+	return box;
+}
+
+
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 /*
@@ -899,6 +1043,7 @@ guint i;
 		);
 
 	combobox = gtk_combo_box_new_with_model(GTK_TREE_MODEL(store));
+	g_object_unref(store);
 
 	renderer = r1 = gtk_cell_renderer_pixbuf_new();
 	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combobox), renderer, FALSE);
@@ -970,13 +1115,7 @@ char *nainex_iconnames[NUM_NAINEX_MAX] =
 	"flt-exclude",
 };
 
-char *nainex_label_names[NUM_NAINEX_MAX] =
-{
-	N_("Inactive"),
-	N_("Include"),
-	N_("Exclude"),
-};
-
+extern gchar *nainex_label_names[];
 
 /*
 ** Make a nainex combobox widget
